import { __awaiter, __generator } from "tslib";
import { SKIPPED_RESPONSE } from '@amplitude/types';
import { logger } from '@amplitude/utils';
import { setupTransportFromOptions } from '../transports';
import { SDK_NAME, SDK_VERSION, DEFAULT_OPTIONS } from '../constants';
var SimpleClient = /** @class */ (function () {
    /**
     * Initializes this client instance.
     *
     * @param apiKey API key for your project
     * @param options options for the client
     */
    function SimpleClient(apiKey, options) {
        if (options === void 0) { options = {}; }
        this._apiKey = apiKey;
        this._options = Object.assign({}, DEFAULT_OPTIONS, options);
        this._transport = this._options.transportClass || setupTransportFromOptions(this._options);
        this._setUpLogging();
    }
    /**
     * @inheritDoc
     */
    SimpleClient.prototype.getOptions = function () {
        return this._options;
    };
    /**
     * @inheritDoc
     */
    SimpleClient.prototype.flush = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                // Noop
                logger.warn('The simple client does nothing when flushing events.');
                return [2 /*return*/, SKIPPED_RESPONSE];
            });
        });
    };
    /**
     * @inheritDoc
     */
    SimpleClient.prototype.logEvent = function (event) {
        if (this._options.optOut === true) {
            return Promise.resolve(SKIPPED_RESPONSE);
        }
        this._annotateEvent(event);
        // Immediately send the event
        return this._transport.sendPayload({ events: [event], api_key: this._apiKey });
    };
    /** Add platform dependent field onto event. */
    SimpleClient.prototype._annotateEvent = function (event) {
        event.library = SDK_NAME + "/" + SDK_VERSION;
        event.platform = 'Node.js';
    };
    SimpleClient.prototype._setUpLogging = function () {
        if (this._options.debug || this._options.logLevel) {
            if (this._options.logLevel) {
                logger.enable(this._options.logLevel);
            }
            else {
                logger.enable();
            }
        }
    };
    return SimpleClient;
}());
export { SimpleClient };
//# sourceMappingURL=simpleClient.js.map