/// <reference types="node" />
import { Payload, Response, Transport, TransportOptions } from '@amplitude/types';
import * as http from 'http';
import * as https from 'https';
import * as url from 'url';
/**
 * Internal used interface for typescript.
 * @hidden
 */
export interface HTTPRequest {
    /**
     * Request wrapper
     * @param options These are {@see TransportOptions}
     * @param callback Callback when request is finished
     */
    request(options: http.RequestOptions | https.RequestOptions | string | url.URL, callback?: (res: http.IncomingMessage) => void): http.ClientRequest;
}
interface RequestQueueObject {
    callback: () => void;
    cancellingTimeout: NodeJS.Timeout | null;
}
/** Base Transport class implementation */
export declare class HTTPTransport implements Transport {
    options: TransportOptions;
    /** The Agent used for corresponding transport */
    module: HTTPRequest;
    protected _uploadInProgress: boolean;
    protected _requestQueue: RequestQueueObject[];
    /** Create instance and set this.dsn */
    constructor(options: TransportOptions);
    /**
     * @inheritDoc
     */
    sendPayload(payload: Payload): Promise<Response>;
    /** Returns a build request option object used by request */
    protected _getRequestOptions(): http.RequestOptions | https.RequestOptions;
    private _awaitUploadFinish;
    private _notifyUploadFinish;
    /** JSDoc */
    protected _sendWithModule(payload: Payload): Promise<Response>;
}
export {};
//# sourceMappingURL=http.d.ts.map